# Contributing

Acoupi is a community effort to facilitate access to bioacoustic models and ease their on-device deployment for field surveys. 

**We warmly welcome contributions, suggestions, fixes and constructive feedback to both acoupi code and documentation.**

